==> wxwidgets2.8_2.8.12.1+dfsg.orig.tar.xz: wxwidgets2.8-2.8.12.1.orig/include/wx/cocoa/stattext.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        wx/cocoa/stattext.h
// Purpose:     wxStaticText class
// Author:      David Elliott
// Modified by:
// Created:     2003/02/15
// RCS-ID:      $Id: stattext.h 47907 2007-08-06 14:55:00Z DE $
// Copyright:   (c) 2003 David Elliott
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#ifndef __WX_COCOA_STATTEXT_H__
#define __WX_COCOA_STATTEXT_H__

#include "wx/cocoa/NSTextField.h"

// ========================================================================
// wxStaticText
// ========================================================================
class WXDLLEXPORT wxStaticText : public wxStaticTextBase, protected wxCocoaNSTextField
{
    DECLARE_DYNAMIC_CLASS(wxStaticText)
    DECLARE_EVENT_TABLE()
    WX_DECLARE_COCOA_OWNER(NSTextField,NSControl,NSView)
// ------------------------------------------------------------------------
// initialization
// ------------------------------------------------------------------------
public:
    wxStaticText() {}
    wxStaticText(wxWindow *parent, wxWindowID winid,
            const wxString& label,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize, long style = 0,
            const wxString& name = wxStaticTextNameStr)
    {
        Create(parent, winid, label, pos, size, style, name);
    }

    bool Create(wxWindow *parent, wxWindowID winid,
            const wxString& label,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize, long style = 0,
            const wxString& name = wxStaticTextNameStr);
    virtual ~wxStaticText();

// ------------------------------------------------------------------------
// Cocoa specifics
// ------------------------------------------------------------------------
protected:
    virtual void Cocoa_didChangeText(void);
// ------------------------------------------------------------------------
// Implementation
// ------------------------------------------------------------------------
public:
    virtual void SetLabel(const wxString& label);
    virtual wxString GetLabel() const;
};

#endif // __WX_COCOA_STATTEXT_H__

==> wxwidgets3.0_3.0.2+dfsg.orig.tar.xz: wxwidgets3.0-3.0.2.orig/include/wx/cocoa/stattext.h <==
/////////////////////////////////////////////////////////////////////////////
// Name:        wx/cocoa/stattext.h
// Purpose:     wxStaticText class
// Author:      David Elliott
// Modified by:
// Created:     2003/02/15
// Copyright:   (c) 2003 David Elliott
// Licence:     wxWindows licence
/////////////////////////////////////////////////////////////////////////////

#ifndef __WX_COCOA_STATTEXT_H__
#define __WX_COCOA_STATTEXT_H__

#include "wx/cocoa/NSTextField.h"

// ========================================================================
// wxStaticText
// ========================================================================
class WXDLLIMPEXP_CORE wxStaticText : public wxStaticTextBase, protected wxCocoaNSTextField
{
    DECLARE_DYNAMIC_CLASS(wxStaticText)
    DECLARE_EVENT_TABLE()
    WX_DECLARE_COCOA_OWNER(NSTextField,NSControl,NSView)
// ------------------------------------------------------------------------
// initialization
// ------------------------------------------------------------------------
public:
    wxStaticText() {}
    wxStaticText(wxWindow *parent, wxWindowID winid,
            const wxString& label,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize, long style = 0,
            const wxString& name = wxStaticTextNameStr)
    {
        Create(parent, winid, label, pos, size, style, name);
    }

    bool Create(wxWindow *parent, wxWindowID winid,
            const wxString& label,
            const wxPoint& pos = wxDefaultPosition,
            const wxSize& size = wxDefaultSize, long style = 0,
            const wxString& name = wxStaticTextNameStr);
    virtual ~wxStaticText();

// ------------------------------------------------------------------------
// Cocoa specifics
// ------------------------------------------------------------------------
protected:
    virtual void Cocoa_didChangeText(void);
// ------------------------------------------------------------------------
// Implementation
// ------------------------------------------------------------------------
public:
    virtual void SetLabel(const wxString& label);
    virtual wxString GetLabel() const;
};

#endif // __WX_COCOA_STATTEXT_H__
